aboutsummaryrefslogtreecommitdiff
path: root/payloads/libpayload/util/kconfig/mconf.c
diff options
context:
space:
mode:
Diffstat (limited to 'payloads/libpayload/util/kconfig/mconf.c')
-rw-r--r--payloads/libpayload/util/kconfig/mconf.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/payloads/libpayload/util/kconfig/mconf.c b/payloads/libpayload/util/kconfig/mconf.c
index 5e93a308d8..fcebc50001 100644
--- a/payloads/libpayload/util/kconfig/mconf.c
+++ b/payloads/libpayload/util/kconfig/mconf.c
@@ -232,7 +232,7 @@ save_config_help[] = N_(
"leave this blank.\n"),
search_help[] = N_(
"\n"
- "Search for CONFIG_ symbols and display their relations.\n"
+ "Search for CONFIG_LP_ symbols and display their relations.\n"
"Regular expressions are allowed.\n"
"Example: search for \"^FOO\"\n"
"Result:\n"
@@ -249,7 +249,7 @@ search_help[] = N_(
"Selected by: BAR\n"
"-----------------------------------------------------------------\n"
"o The line 'Prompt:' shows the text used in the menu structure for\n"
- " this CONFIG_ symbol\n"
+ " this CONFIG_LP_ symbol\n"
"o The 'Defined at' line tell at what file / line number the symbol\n"
" is defined\n"
"o The 'Depends on:' line tell what symbols needs to be defined for\n"
@@ -265,9 +265,9 @@ search_help[] = N_(
"Only relevant lines are shown.\n"
"\n\n"
"Search examples:\n"
- "Examples: USB => find all CONFIG_ symbols containing USB\n"
- " ^USB => find all CONFIG_ symbols starting with USB\n"
- " USB$ => find all CONFIG_ symbols ending with USB\n"
+ "Examples: USB => find all CONFIG_LP_ symbols containing USB\n"
+ " ^USB => find all CONFIG_LP_ symbols starting with USB\n"
+ " USB$ => find all CONFIG_LP_ symbols ending with USB\n"
"\n");
static int indent;
@@ -388,8 +388,8 @@ static void search_conf(void)
again:
dialog_clear();
dres = dialog_inputbox(_("Search Configuration Parameter"),
- _("Enter CONFIG_ (sub)string to search for "
- "(with or without \"CONFIG\")"),
+ _("Enter CONFIG_LP_ (sub)string to search for "
+ "(with or without \"CONFIG_LP\")"),
10, 75, "");
switch (dres) {
case 0:
@@ -401,9 +401,9 @@ again:
return;
}
/* strip CONFIG_ if necessary */
dialog_input = dialog_input_result;
- if (strncasecmp(dialog_input_result, "CONFIG_", 7) == 0)
+ if (strncasecmp(dialog_input_result, "CONFIG_LP_", 10) == 0)
dialog_input += 7;
sym_arr = sym_re_search(dialog_input);
@@ -704,7 +704,7 @@ static void show_help(struct menu *menu)
if (menu_has_help(menu))
{
if (sym->name) {
- str_printf(&help, "CONFIG_%s:\n\n", sym->name);
+ str_printf(&help, "CONFIG_LP_%s:\n\n", sym->name);
str_append(&help, _(menu_get_help(menu)));
str_append(&help, "\n");
}
@@ -401,9 +401,9 @@ again:
return;
}
- /* strip CONFIG_ if necessary */
+ /* strip CONFIG_LP_ if necessary */
dialog_input = dialog_input_result;